@@ -21,7 +21,7 @@ static BOOL gCompletionLastSqort;
 static BOOL gCompletionLastDqort;
 static int gCompletionCandidateLen;
 static int gEditingLen;
-static char gEditing[2048];
+static char gEditing[kCmdLineMax];
 static int gCmdLineCompletionMaxRow;
 
 static int gCompletionScrollTop = 0;
@@ -52,7 +52,7 @@ void cmdline_completion_init()
     gEnvirons = VECTOR_NEW(5);
     char** p;
     for(p = environ; *p; p++) {
-        char env_name[256];
+        char env_name[PATH_MAX];
 
         char* p2 = env_name;
         char* p3 = *p;
@@ -128,20 +128,20 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
             string_obj* str = vector_item(all_candidate, i);
 
             char* src = string_c_str(str);
-            char* des = MALLOC(strlen(src)*2);
             int des_size = strlen(src)*2;
-#if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) 
+            char* des = MALLOC(des_size+1);
+#if defined(__DARWIN__)
             if(is_all_ascii(src)) {
-                strcpy(des, src);
+                strncpy(des, src, des_size);
             }
             else {
                 /// コンバート ///
                 if(kanji_convert(src, des, des_size, gKanjiCodeFileName, gKanjiCode) < 0) {
-                    strcpy(des, src);
+                    strncpy(des, src, des_size);
                 }
             }
 #else
-            strcpy(des, src);
+            strncpy(des, src, des_size);
 #endif
             vector_add(all_candidate2, STRING_NEW(des));
             FREE(des);
@@ -156,7 +156,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
     }
 
     gCompletionAddSpace = add_space;
-    strcpy(gEditing, editing);
+    strncpy(gEditing, editing, kCmdLineMax);
     gEditingLen = strlen(gEditing);
 
     cmdline_completion_clear();
@@ -214,11 +214,11 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
 
                     if(utf8_len == utf8_size) {
                         utf8[utf8_len] = 0;
-                        sprintf(tmp, "%s", utf8);
+                        snprintf(tmp, 256, "%s", utf8);
                         string_insert(str, gCmdLineCursor, tmp);
                         gCmdLineCursor+=utf8_len;
                         gEditingLen+=utf8_len;
-                        strcat(gEditing, tmp);
+                        strncat(gEditing, tmp, kCmdLineMax);
                         utf8_size = -1;
                         utf8_len = 0;
                     }
@@ -226,20 +226,20 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
                 else {
                     if(!gCompletionSqort && !gCompletionDqort && (c==' ' || c=='!' || c=='*' || c=='>' || c=='&' || c=='~' || c=='#' || c =='$' || c=='(' || c==')' || c=='\\' || c=='|' || c=='[' || c==']' || c=='{' || c=='}' || c==';' || c=='\'' || c=='"' || c=='<' || c=='>' || c=='?'))
                     {
-                        sprintf(tmp, "\\%c", c);
+                        snprintf(tmp, 256, "\\%c", c);
                         string_insert(str, gCmdLineCursor, tmp);
                         gCmdLineCursor+=2;
 
                         gEditingLen++;
-                        sprintf(gEditing + strlen(gEditing), "%c", c);
+                        snprintf(gEditing + strlen(gEditing), kCmdLineMax - strlen(gEditing), "%c", c);
                     }
                     else {
-                        sprintf(tmp, "%c", c);
+                        snprintf(tmp, 256, "%c", c);
                         string_insert(str, gCmdLineCursor, tmp);
                         gCmdLineCursor++;
 
                         gEditingLen++;
-                        strcat(gEditing, tmp);
+                        strncat(gEditing, tmp, kCmdLineMax);
                     }
                 }
             }
@@ -254,13 +254,13 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
             if(c != '/') {
                 if(gCompletionSqort && !gCompletionLastSqort) {
                     char tmp[128];
-                    sprintf(tmp, "' ");
+                    snprintf(tmp, 128, "' ");
                     string_insert(str, gCmdLineCursor, tmp);
                     gCmdLineCursor+=2;
                 }
                 else if(gCompletionDqort && !gCompletionLastDqort) {
                     char tmp[128];
-                    sprintf(tmp, "\" ");
+                    snprintf(tmp, 128, "\" ");
                     string_insert(str, gCmdLineCursor, tmp);
                     gCmdLineCursor+=2;
                 }
@@ -268,7 +268,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
                         && !gCompletionLastDqort)
                 {
                     char tmp[128];
-                    sprintf(tmp, " ");
+                    snprintf(tmp, 128, " ");
                     string_insert(str, gCmdLineCursor, tmp);
                     gCmdLineCursor++;
                 }
@@ -286,154 +286,20 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
     vector_delete(all_candidate2);
 }
 
-///////////////////////////////////////////////////
-// コマンドライン補完2
-///////////////////////////////////////////////////
-void cmdline_completion2(vector_obj* all_candidate, char* editing, BOOL add_space, int candidate_len)
-{
-    string_obj* str = gCmdLine;
-    char* cstr = string_c_str(str);
-
-    /// go ///
-    gCompletionAddSpace = add_space;
-    gCompletionCandidateLen = candidate_len;
-    gEditingLen = strlen(editing);
-    strcpy(gEditing, editing);
-
-    cmdline_completion_clear();
-
-    if(strcmp(editing, "") == 0) {
-        int i;
-        for(i=0; i<vector_size(all_candidate); i++) {
-            vector_obj* array = vector_item(all_candidate, i);
-
-            vector_add(gCCandidate, vector_item(array, 0));
-            vector_add(gCExplanation, vector_item(array, 1));
-        }
-    }
-    else {
-        int i;
-        for(i=0; i<vector_size(all_candidate); i++) {
-            vector_obj* array = vector_item(all_candidate, i);
-
-            if(strstr(string_c_str(vector_item(array, 0)), editing) == string_c_str(vector_item(array, 0)))
-            {
-                vector_add(gCCandidate, vector_item(array, 0));
-                vector_add(gCExplanation, vector_item(array, 1));
-            }
-        }
-    }
-
-    if(vector_size(gCCandidate) > 0) {
-        int l = strlen(editing);
-
-        const int len = strlen((char*)vector_item(gCCandidate, 0));
-        char c = 0;
-        BOOL kanji = FALSE;
-        while(l < len) {
-            BOOL same = TRUE;
-
-            int i;
-            for(i= 0; i<vector_size(gCCandidate); i++) {
-                char* item = (char*)vector_item(gCCandidate, i);
-
-                if(item[l] != ((char*)vector_item(gCCandidate, 0))[l]) {
-                    same = FALSE;
-                }
-            }
-
-            if(same) {
-                char tmp[256];
-                c = ((char*)vector_item(gCCandidate, 0))[l];
-                
-                BOOL kanji_before = kanji;
-                if(gKanjiCode != kUtf8) {
-                    if(kanji) {
-                        kanji = FALSE;
-                    }
-                    else {
-                        if(is_kanji(kUtf8, c)) {
-                            kanji = TRUE;
-                        }
-                    }
-                }
-
-                if(!gCompletionSqort && !gCompletionDqort && (gKanjiCode==kUtf8 || !kanji_before) && (c==' ' || c=='!' || c=='*' || c=='>' || c=='&' || c=='~' || c=='#' || c =='$' || c=='(' || c==')' || c=='\\' || c=='|' || c=='[' || c==']' || c=='{' || c=='}' || c==';' || c=='\'' || c=='"' || c=='<' || c=='>' || c=='?'))
-                {
-                    sprintf(tmp, "\\%c", c);
-                    string_insert(str, gCmdLineCursor, tmp);
-                    gCmdLineCursor+=2;
-
-                    gEditingLen++;
-                    sprintf(gEditing + strlen(gEditing), "%c", c);
-                }
-                else {
-                    sprintf(tmp, "%c", c);
-                    string_insert(str, gCmdLineCursor, tmp);
-                    gCmdLineCursor++;
-
-                    gEditingLen++;
-                    strcat(gEditing, tmp);
-                }
-            }
-            else {
-                break;
-            }
-
-            l++;
-        }
-
-        if(kanji) {
-            gCmdLineCursor--;
-            string_erase(str, gCmdLineCursor, 1);
-            gEditingLen--;
-            gEditing[strlen(gEditing)-1] = 0;
-        }
-
-        if(l == len && vector_size(gCCandidate) == 1 && c != '/') {
-            if(c != '/') {
-                if(gCompletionSqort && !gCompletionLastSqort) {
-                    char tmp[128];
-                    sprintf(tmp, "' ");
-                    string_insert(str, gCmdLineCursor, tmp);
-                    gCmdLineCursor+=2;
-                }
-                else if(gCompletionDqort && !gCompletionLastDqort) {
-                    char tmp[128];
-                    sprintf(tmp, "\" ");
-                    string_insert(str, gCmdLineCursor, tmp);
-                    gCmdLineCursor+=2;
-                }
-                else if(gCompletionAddSpace && !gCompletionLastSqort
-                        && !gCompletionLastDqort)
-                {
-                    char tmp[128];
-                    sprintf(tmp, " ");
-                    string_insert(str, gCmdLineCursor, tmp);
-                    gCmdLineCursor++;
-                }
-            }
-
-            cmdline_completion_clear();
-        }
-    }
-    cmdline_convert();
-}
-
 ///////////////////////////////////////////////////
 // ファイル名の補完
 ///////////////////////////////////////////////////
 void cmdline_completion_file(char* editing_dir, char* editing_file, char* editing, int editing_position)
 {
     char editing_dir2[kCmdLineMax];
-    strcpy(editing_dir2, editing_dir);
+    strncpy(editing_dir2, editing_dir, kCmdLineMax);
 
     /// editing_dirが存在するなら ///
     if(strcmp(editing_dir2, "") != 0) {
         /// 環境変数から始まっている場合 ///
         if(editing_dir2[0] == '$') {
             char new_editing_dir[kCmdLineMax];
-            char env_name[256];
+            char env_name[PATH_MAX];
 
             char *p = editing_dir2;
             p++;
@@ -447,10 +313,10 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             
             char* env = getenv(env_name);
             if(env) {
-                strcpy(new_editing_dir, env);
-                strcat(new_editing_dir, p);
+                strncpy(new_editing_dir, env, kCmdLineMax);
+                strncat(new_editing_dir, p, kCmdLineMax);
 
-                strcpy(editing_dir2, new_editing_dir);
+                strncpy(editing_dir2, new_editing_dir, PATH_MAX);
             }
         }
 
@@ -461,10 +327,10 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             char* p = editing_dir2;
             p++;
 
-            strcpy(new_editing_dir, getenv("HOME"));
-            strcat(new_editing_dir, p);
+            strncpy(new_editing_dir, getenv("HOME"), kCmdLineMax);
+            strncat(new_editing_dir, p, kCmdLineMax);
 
-            strcpy(editing_dir2, new_editing_dir);
+            strncpy(editing_dir2, new_editing_dir, kCmdLineMax);
         }
 
         DIR* dir = opendir(editing_dir2);
@@ -479,13 +345,12 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
                     char buf[PATH_MAX];
 
                     struct stat _stat;
-                    strcpy(buf, editing_dir2);
-                    strcat(buf, entry->d_name);
+                    snprintf(buf, PATH_MAX, "%s%s", editing_dir2, entry->d_name);
                     stat(buf, &_stat);
 
-                    strcpy(buf, entry->d_name);
+                    strncpy(buf, entry->d_name, PATH_MAX);
                     if(S_ISDIR(_stat.st_mode)) {
-                        strcat(buf, "/");
+                        strncat(buf, "/", PATH_MAX);
                     }
 
                     vector_add(files, STRING_NEW(buf));
@@ -530,13 +395,12 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
                         char buf[PATH_MAX];
 
                         struct stat _stat;
-                        strcpy(buf, "./");
-                        strcat(buf, entry->d_name);
+                        snprintf(buf, PATH_MAX, "./%s", entry->d_name);
                         stat(buf, &_stat);
 
-                        strcpy(buf, entry->d_name);
+                        strncpy(buf, entry->d_name, PATH_MAX);
                         if(S_ISDIR(_stat.st_mode)) {
-                            strcat(buf, "/");
+                            strncat(buf, "/", PATH_MAX);
                         }
                         vector_add(files, STRING_NEW(buf));
                     }
@@ -672,8 +536,8 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
     *e = 0;
     *editing_position = 0;
-    strcpy(cmdname, "");
-    strcpy(editing_before, "");
+    strncpy(cmdname, "", kCmdLineMax);
+    strncpy(editing_before, "", kCmdLineMax);
     *squote = FALSE;
     *dquote = FALSE;
     *last_squote = FALSE;
@@ -708,10 +572,10 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             *e = 0;
             vector_add(*earray, STRING_NEW(editing));
-            strcpy(editing_before, editing);
+            strncpy(editing_before, editing, kCmdLineMax);
 
             if(editing[0] != '%' && editing[0] != '-') {
-                if(*editing_position == 0) strcpy(cmdname, editing);
+                if(*editing_position == 0) strncpy(cmdname, editing, kCmdLineMax);
                 (*editing_position)++;
             }
 
@@ -725,10 +589,10 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             *e = 0;
             vector_add(*earray, STRING_NEW(editing));
-            strcpy(editing_before, editing);
+            strncpy(editing_before, editing, kCmdLineMax);
 
             if(editing[0] != '%' && editing[0] != '-') {
-                if(*editing_position == 0) strcpy(cmdname, editing);
+                if(*editing_position == 0) strncpy(cmdname, editing, kCmdLineMax);
                 (*editing_position)++;
             }
 
@@ -742,11 +606,11 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             *e = 0;
             vector_add(*earray, STRING_NEW(editing));
-            strcpy(editing_before, editing);
+            strncpy(editing_before, editing, kCmdLineMax);
 
             e = editing;
 
-            strcpy(cmdname, "");                
+            strncpy(cmdname, "", kCmdLineMax);
             *editing_position = 0;
             int i;
             for(i=0; i<vector_size(*earray); i++) {
@@ -764,10 +628,9 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     }
     *e = 0;
     vector_add(*earray, STRING_NEW(editing));
-    //strcpy(editing_before, editing);
     if(editing[0] != '%' && editing[0] != '-')
     {
-        if(*editing_position == 0) strcpy(cmdname, editing);
+        if(*editing_position == 0) strncpy(cmdname, editing, kCmdLineMax);
     }
 
     if(strlen(cmdline) >= gCmdLineCursor && cmdline[gCmdLineCursor] == '\'') {
@@ -779,8 +642,8 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     }
 
     /// divide editing into dir part and file part ///
-    strcpy(editing_dir, "");
-    strcpy(editing_file, "");
+    strncpy(editing_dir, "", kCmdLineMax);
+    strncpy(editing_file, "", kCmdLineMax);
 
     e = editing + strlen(editing);
     while(e >= editing) {
@@ -797,7 +660,7 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     }
 
     if(strcmp(editing_dir, "") == 0) {
-        strcpy(editing_file, editing);
+        strncpy(editing_file, editing, kCmdLineMax);
     }
 
     int i;
@@ -908,32 +771,6 @@ void cmdline_completion_view()
             //int editing_len2 = strlen(gEditing);
 
             if(editing_len < maxx/gCmdLineCompletionMaxRow-1) {
-/*
-                char tmp[4096];
-                str_cut2(kUtf8, item, editing_len, tmp, 4096);
-
-                char tmp2[4096];
-                str_cut2(kUtf8, item + editing_len2, maxx/gCmdLineCompletionMaxRow-1-editing_len, tmp2, 4096);
-
-                if(gCompletionCursor == i) {
-                    mattron(kCAReverse);
-                    mmvprintw(line, row * (maxx/gCmdLineCompletionMaxRow), "%s", tmp);
-                    mprintw("%s", tmp2);
-                    mattroff();
-                }
-                else {
-                    char* env = getenv("CMDLINE_COLOR");
-                    if(env && strcmp(env, "1") == 0) 
-                        mattron(kCACyan); 
-                    else 
-                        mattron(kCABold);
-
-                    mmvprintw(line, row * (maxx/gCmdLineCompletionMaxRow)
-                                        , "%s", tmp);
-                    //mattroff();
-                    mprintw("%s", tmp2);
-                }
-*/
                 if(gCompletionCursor == i) {
                     mattron(kCAReverse);
                     mmvprintw(line, row * (maxx/gCmdLineCompletionMaxRow) , "%s", item);
@@ -971,10 +808,10 @@ void cmdline_completion_view()
                             vector_item(gCExplanation, i));
 
             char tmp[256];
-            sprintf(tmp, "%%-%ds %%s", gCompletionCandidateLen);
+            snprintf(tmp, 256, "%%-%ds %%s", gCompletionCandidateLen);
 
             char buf[4096];
-            sprintf(buf, tmp, item, explanation);
+            snprintf(buf, 4096, tmp, item, explanation);
 
             char tmp2[4096];
             str_cut2(kUtf8, buf, maxx-1, tmp2, 256);
