@@ -158,7 +158,7 @@ BOOL commands_cursor_move(int* rcode, vector_obj* argv, vector_obj* blocks, vect
 
     if(*rcode == 0) {
         char buf[128];
-        sprintf(buf, "cursor_move_hook %d", dir);
+        snprintf(buf, 128, "cursor_move_hook %d", dir);
         int rcode2 = saphire_shell(buf, "cursor_move_hook", nextout, nextin, nexterr);
         saphire_sweep();
 
@@ -239,7 +239,7 @@ BOOL commands_mcd(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
     /// フック ///
     if(*rcode == 0) {
         char buf[128];
-        sprintf(buf, "mcd_hook %d", dir);
+        snprintf(buf, 128, "mcd_hook %d", dir);
 
         int rcode2 = saphire_shell(buf, "mcd_hook", nextout, nextin, nexterr);
         saphire_sweep();
@@ -401,7 +401,7 @@ BOOL commands_file_ext(int* rcode, vector_obj* argv, vector_obj* blocks, vector_
         sFile* file = filer_file(dir, atoi(argv2));
         if(file) {
             char buf[PATH_MAX];
-            extname(buf, string_c_str(file->mName));
+            extname(buf, PATH_MAX, string_c_str(file->mName));
             if(!statment_tree_internal_commands_write_nextout(nextout, buf))
             {
                 return FALSE;
@@ -453,7 +453,7 @@ BOOL commands_file_index(int* rcode, vector_obj* argv, vector_obj* blocks, vecto
         char* argv1 = string_c_str((string_obj*)vector_item(argv, 1));
 
         char buf[BUFSIZ];
-        sprintf(buf, "%d", filer_file2(dir, argv1));
+        snprintf(buf, BUFSIZ, "%d", filer_file2(dir, argv1));
 
         if(!statment_tree_internal_commands_write_nextout(nextout, buf))
         {
@@ -615,7 +615,7 @@ BOOL commands_file_perm(int* rcode, vector_obj* argv, vector_obj* blocks, vector
             int n = file->mLStat.st_mode & S_ALLPERM;
 
             char buf[BUFSIZ];
-            sprintf(buf, "%o", n);
+            snprintf(buf, BUFSIZ, "%o", n);
             if(!statment_tree_internal_commands_write_nextout(nextout, buf))
             {
                 return FALSE;
@@ -667,7 +667,7 @@ BOOL commands_file_num(int* rcode, vector_obj* argv, vector_obj* blocks, vector_
         sDir* dir2 = filer_dir(dir);
         if(dir2) {
             char buf[BUFSIZ];
-            sprintf(buf, "%d", vector_size(dir2->mFiles));
+            snprintf(buf, BUFSIZ, "%d", vector_size(dir2->mFiles));
             if(!statment_tree_internal_commands_write_nextout(nextout, buf))
             {
                 return FALSE;
@@ -683,7 +683,7 @@ BOOL commands_dir_num(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
 {
     if(vector_size(argv) == 1) {
         char buf[BUFSIZ];
-        sprintf(buf, "%d", vector_size(gDirs));
+        snprintf(buf, BUFSIZ, "%d", vector_size(gDirs));
         if(!statment_tree_internal_commands_write_nextout(nextout, buf))
         {
             return FALSE;
@@ -734,7 +734,7 @@ BOOL commands_cursor_num(int* rcode, vector_obj* argv, vector_obj* blocks, vecto
 
         if(dir2) {
             char buf[BUFSIZ];
-            sprintf(buf, "%d", dir2->mCursor);
+            snprintf(buf, BUFSIZ, "%d", dir2->mCursor);
             if(!statment_tree_internal_commands_write_nextout(nextout, buf))
             {
                 return FALSE;
@@ -906,7 +906,7 @@ BOOL commands_activate(int* rcode, vector_obj* argv, vector_obj* blocks, vector_
         *rcode = 0;
 
         char buf[128];
-        sprintf(buf, "activate_hook %d", n);
+        snprintf(buf, 128, "activate_hook %d", n);
 
         int rcode2 = saphire_shell(buf, "activate_hook", nextout, nextin, nexterr);
         saphire_sweep();
@@ -1106,8 +1106,8 @@ BOOL commands_allfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector_
                             && strcmp(string_c_str(file->mName), "..") != 0) 
                         {
                             char path[PATH_MAX];
-                            strcpy(path, string_c_str(dir2->mPath));
-                            strcat(path, string_c_str(file->mName));
+                            strncpy(path, string_c_str(dir2->mPath), PATH_MAX);
+                            strncat(path, string_c_str(file->mName), PATH_MAX);
 
                             string_obj* str = STRING_NEW("");
                             if(quote) {
@@ -1143,8 +1143,8 @@ BOOL commands_allfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector_
                         && strcmp(string_c_str(file->mName), "..") != 0) 
                     {
                         char path[PATH_MAX];
-                        strcpy(path, string_c_str(dir2->mPath));
-                        strcat(path, string_c_str(file->mName));
+                        strncpy(path, string_c_str(dir2->mPath), PATH_MAX);
+                        strncat(path, string_c_str(file->mName), PATH_MAX);
 
                         string_obj* str = STRING_NEW("");
                         if(quote) {
@@ -1312,8 +1312,8 @@ BOOL commands_markfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector
                             sFile* file = vector_item(dir2->mFiles, j);
                             if(file->mMark) {
                                 char path[PATH_MAX];
-                                strcpy(path, string_c_str(dir2->mPath));
-                                strcat(path, string_c_str(file->mName));
+                                strncpy(path, string_c_str(dir2->mPath), PATH_MAX);
+                                strncat(path, string_c_str(file->mName), PATH_MAX);
 
                                 string_obj* str = STRING_NEW("");
                                 if(quote) {
@@ -1343,8 +1343,8 @@ BOOL commands_markfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector
                         sFile* file = filer_cursor_file(i);
 
                         char path[PATH_MAX];
-                        strcpy(path, string_c_str(dir2->mPath));
-                        strcat(path, string_c_str(file->mName));
+                        strncpy(path, string_c_str(dir2->mPath), PATH_MAX);
+                        strncat(path, string_c_str(file->mName), PATH_MAX);
 
                         string_obj* str = STRING_NEW("");
                         if(quote) {
@@ -1373,8 +1373,8 @@ BOOL commands_markfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector
                         sFile* file = vector_item(dir2->mFiles, j);
                         if(file->mMark) {
                             char path[PATH_MAX];
-                            strcpy(path, string_c_str(dir2->mPath));
-                            strcat(path, string_c_str(file->mName));
+                            strncpy(path, string_c_str(dir2->mPath), PATH_MAX);
+                            strncat(path, string_c_str(file->mName), PATH_MAX);
 
                             string_obj* str = STRING_NEW("");
                             if(quote) {
@@ -1404,8 +1404,8 @@ BOOL commands_markfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector
                     sFile* file = filer_cursor_file(dir);
 
                     char path[PATH_MAX];
-                    strcpy(path, string_c_str(dir2->mPath));
-                    strcat(path, string_c_str(file->mName));
+                    strncpy(path, string_c_str(dir2->mPath), PATH_MAX);
+                    strncat(path, string_c_str(file->mName), PATH_MAX);
 
                     string_obj* str = STRING_NEW("");
                     if(quote) {
@@ -2112,7 +2112,7 @@ BOOL commands_mrename(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
 BOOL commands_row(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
-    sprintf(buf, "%d", filer_row(adir()));
+    snprintf(buf, BUFSIZ, "%d", filer_row(adir()));
     if(!statment_tree_internal_commands_write_nextout(nextout, buf))
     {
         return FALSE;
@@ -2125,7 +2125,7 @@ BOOL commands_row(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
 BOOL commands_row_max(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
-    sprintf(buf, "%d", filer_row_max(adir()));
+    snprintf(buf, BUFSIZ, "%d", filer_row_max(adir()));
     if(!statment_tree_internal_commands_write_nextout(nextout, buf))
     {
         return FALSE;
@@ -2138,7 +2138,7 @@ BOOL commands_row_max(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
 BOOL commands_line(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
-    sprintf(buf, "%d", filer_line(adir()));
+    snprintf(buf, BUFSIZ, "%d", filer_line(adir()));
     if(!statment_tree_internal_commands_write_nextout(nextout, buf))
     {
         return FALSE;
@@ -2152,7 +2152,7 @@ BOOL commands_line(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
 BOOL commands_line_max(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
-    sprintf(buf, "%d", filer_line_max(adir()));
+    snprintf(buf, BUFSIZ, "%d", filer_line_max(adir()));
     if(!statment_tree_internal_commands_write_nextout(nextout, buf))
     {
         return FALSE;
@@ -2205,12 +2205,12 @@ BOOL commands_mcp(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
 
         /// 引数チェック ///
         char distination[PATH_MAX];
-        strcpy(distination, string_c_str(vector_item(argv, 1)));
+        strncpy(distination, string_c_str(vector_item(argv, 1)), PATH_MAX);
 
         /// 対象がディレクトリかチェック ///
         if(distination[strlen(distination)-1] != '/')
         {
-            strcat(distination, "/");
+            strncat(distination, "/", PATH_MAX);
         }
 
         /// ディレクトリが無いなら作成 ///
@@ -2220,10 +2220,10 @@ BOOL commands_mcp(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             };
 
             char buf[BUFSIZ];
-            sprintf(buf, "%s doesn't exist. create?", distination);
+            snprintf(buf, BUFSIZ, "%s doesn't exist. create?", distination);
 
             if(select_str(buf, str, 2, 1) == 0) {
-                sprintf(buf, "mkdir -p %s", distination);
+                snprintf(buf, BUFSIZ, "mkdir -p %s", distination);
                 system(buf);
             }
             else {
@@ -2251,8 +2251,8 @@ BOOL commands_mcp(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             char* fname = string_c_str(file->mName);
             char source[PATH_MAX];
 
-            strcpy(source, string_c_str(dir->mPath));
-            strcat(source, fname);
+            strncpy(source, string_c_str(dir->mPath), PATH_MAX);
+            strncat(source, fname, PATH_MAX);
             
             if(strcmp(fname, ".") != 0 && strcmp(fname, "..") != 0) {
                 int num;
@@ -2334,8 +2334,8 @@ BOOL commands_mbackup(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
 
         /// 引数チェック ///
         char distination[PATH_MAX];
-        strcpy(distination, string_c_str(dir->mPath));
-        strcat(distination, string_c_str(vector_item(argv, 1)));
+        strncpy(distination, string_c_str(dir->mPath), PATH_MAX);
+        strncat(distination, string_c_str(vector_item(argv, 1)), PATH_MAX);
 
         /// 対象があるかどうかチェック ///
         if(access(distination, F_OK) == 0) {
@@ -2349,8 +2349,8 @@ BOOL commands_mbackup(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
         char* fname = string_c_str(file->mName);
         char source[PATH_MAX];
 
-        strcpy(source, string_c_str(dir->mPath));
-        strcat(source, fname);
+        strncpy(source, string_c_str(dir->mPath), PATH_MAX);
+        strncat(source, fname, PATH_MAX);
             
         if(strcmp(fname, ".") != 0 && strcmp(fname, "..") != 0) {
             int num;
@@ -2424,11 +2424,11 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
 
         /// 引数チェック ///
         char distination[PATH_MAX];
-        strcpy(distination, string_c_str(vector_item(argv, 1)));
+        strncpy(distination, string_c_str(vector_item(argv, 1)), PATH_MAX);
 
         /// 対象がディレクトリ ///
         if(distination[strlen(distination)-1] != '/') {
-            strcat(distination, "/");
+            strncat(distination, "/", PATH_MAX);
         }
 
         /// ディレクトリが無いなら作成 ///
@@ -2439,10 +2439,10 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             };
 
             char buf[BUFSIZ];
-            sprintf(buf, "%s doesn't exist. create?", distination);
+            snprintf(buf, BUFSIZ, "%s doesn't exist. create?", distination);
 
             if(select_str(buf, str, 2, 1) == 0) {
-                sprintf(buf, "mkdir -p %s", distination);
+                snprintf(buf, BUFSIZ, "mkdir -p %s", distination);
                 system(buf);
             }
             else {
@@ -2471,8 +2471,8 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             char* fname = string_c_str(file->mName);
             char source[PATH_MAX];
 
-            strcpy(source, string_c_str(dir->mPath));
-            strcat(source, fname);
+            strncpy(source, string_c_str(dir->mPath), PATH_MAX);
+            strncat(source, fname, PATH_MAX);
 
             if(strcmp(fname, ".") != 0 && strcmp(fname, "..") != 0) {
                 int num;
@@ -2541,8 +2541,8 @@ BOOL commands_mrm(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
                 char source[PATH_MAX];
 
                 sDir* dir = filer_dir(adir());
-                strcpy(source, string_c_str(dir->mPath));
-                strcat(source, item);
+                strncpy(source, string_c_str(dir->mPath), PATH_MAX);
+                strncat(source, item, PATH_MAX);
 
                 int num;
                 if((num = filer_file2(adir(), item)) < 0) {
@@ -2672,15 +2672,15 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, vector_obj* blocks, vector
 
         char* env = getenv("TRASHBOX_DIR");
         if(env) {
-            strcpy(distination, env);
+            strncpy(distination, env, PATH_MAX);
         }
         else {
-            strcpy(distination, getenv("MF3HOME"));
-            strcat(distination, "/trashbox/");
+            strncpy(distination, getenv("MF3HOME"), PATH_MAX);
+            strncat(distination, "/trashbox/", PATH_MAX);
         }
 
         if(distination[strlen(distination)-1] != '/') {
-            strcat(distination, "/");
+            strncat(distination, "/", PATH_MAX);
         }
 
         /// ディレクトリが無いなら作成 ///
@@ -2691,10 +2691,10 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, vector_obj* blocks, vector
             };
 
             char buf[BUFSIZ];
-            sprintf(buf, "%s doesn't exist. create?", distination);
+            snprintf(buf, BUFSIZ, "%s doesn't exist. create?", distination);
 
             if(select_str(buf, str, 2, 1) == 0) {
-                sprintf(buf, "mkdir -p %s", distination);
+                snprintf(buf, BUFSIZ, "mkdir -p %s", distination);
                 system(buf);
             }
             else {
@@ -2723,8 +2723,8 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, vector_obj* blocks, vector
             char* fname = string_c_str(file->mName);
             char source[PATH_MAX];
 
-            strcpy(source, string_c_str(dir->mPath));
-            strcat(source, fname);
+            strncpy(source, string_c_str(dir->mPath), PATH_MAX);
+            strncat(source, fname, PATH_MAX);
 
             if(strcmp(fname, ".") != 0 && strcmp(fname, "..") != 0) {
                 int num;
@@ -2778,10 +2778,10 @@ BOOL commands_mln(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
     if(vector_size(argv) == 2) {
         /// 引数チェック ///
         char distination[PATH_MAX];
-        strcpy(distination, string_c_str(vector_item(argv, 1)));
+        strncpy(distination, string_c_str(vector_item(argv, 1)), PATH_MAX);
 
         if(distination[strlen(distination)-1] != '/') {
-            strcat(distination, "/");
+            strncat(distination, "/", PATH_MAX);
         }
 
         /// ディレクトリが無いなら作成 ///
@@ -2791,10 +2791,10 @@ BOOL commands_mln(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             };
 
             char buf[BUFSIZ];
-            sprintf(buf, "%s doesn't exist. create?", distination);
+            snprintf(buf, BUFSIZ, "%s doesn't exist. create?", distination);
 
             if(select_str(buf, str, 2, 1) == 0) {
-                sprintf(buf, "mkdir -p %s", distination);
+                snprintf(buf, BUFSIZ, "mkdir -p %s", distination);
                 system(buf);
             }
             else {
@@ -2822,8 +2822,8 @@ BOOL commands_mln(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             char* fname = string_c_str(file->mName);
             char source[PATH_MAX];
 
-            strcpy(source, string_c_str(dir->mPath));
-            strcat(source, fname);
+            strncpy(source, string_c_str(dir->mPath), PATH_MAX);
+            strncat(source, fname, PATH_MAX);
 
             if(strcmp(fname, ".") != 0 && strcmp(fname, "..") != 0) {
                 int num;
@@ -2841,8 +2841,8 @@ BOOL commands_mln(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
                     mrefresh();
 
                     char dfile[PATH_MAX];
-                    strcpy(dfile, distination);
-                    strcat(dfile, fname);
+                    strncpy(dfile, distination, PATH_MAX);
+                    strncat(dfile, fname, PATH_MAX);
 
                     if(symlink(source, dfile) < 0) {
                         merr_msg("can't make symlink(%s). Is it attempt to make on vfat?", dfile);
@@ -2914,10 +2914,10 @@ BOOL commands_mchoise(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
         char* smsg = choise(msg, str, vector_size(argv) -2, -1);
         char buf[BUFSIZ];
         if(smsg == NULL) {
-            sprintf(buf, "cancel");
+            snprintf(buf, BUFSIZ, "cancel");
         }
         else {
-            sprintf(buf, "%s", smsg);
+            snprintf(buf, BUFSIZ, "%s", smsg);
         }
 
         if(!statment_tree_internal_commands_write_nextout(nextout, buf))
@@ -2936,7 +2936,7 @@ BOOL commands_mchoise(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
 BOOL commands_adir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[256];
-    sprintf(buf, "%d", adir());
+    snprintf(buf, 256, "%d", adir());
     if(!statment_tree_internal_commands_write_nextout(nextout, buf))
     {
         return FALSE;
@@ -2950,7 +2950,7 @@ BOOL commands_adir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
 BOOL commands_sdir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[256];
-    sprintf(buf, "%d", sdir());
+    snprintf(buf, 256, "%d", sdir());
     if(!statment_tree_internal_commands_write_nextout(nextout, buf))
     {
         return FALSE;
