@@ -4,49 +4,32 @@
 #include "config.h"
 
 #if defined(__CYGWIN__)
-#define _LARGEFILE64_SOURCE       // サイズが大きいファイルを扱うために必要
 
+#define _LARGEFILE64_SOURCE       // サイズが大きいファイルを扱うために必要
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
 #define stat64 stat
 #define __off64_t long long int
 #define lstat64 lstat
 #undef _LARGEFILE64_SOURCE
+
 #elif defined(__DARWIN__)
 
+#define _LARGEFILE64_SOURCE       // サイズが大きいファイルを扱うために必要
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
-#define stat64 stat
 #define __off64_t long long int
+#define stat64 stat
 #define lstat64 lstat
-#elif defined(__LINUX__)
-#define _LARGEFILE64_SOURCE      // サイズが大きいファイルを扱うために必要
+#undef _LARGEFILE64_SOURCE
 
+#elif defined(__LINUX__)
+
+#define _LARGEFILE64_SOURCE      // サイズが大きいファイルを扱うために必要
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
 #include <linux/stat.h>
 
-#undef _LARGEFILE64_SOURCE
-
-extern int lstat (__const char *__restrict __file,
-    struct stat *__restrict __buf) __attribute__ ((__nothrow__)) __attribute__ ((__nonnull__ (1, 2)));
-
-extern int lstat64 (__const char *__restrict __file,
-      struct stat64 *__restrict __buf)
-     __attribute__ ((__nothrow__)) __attribute__ ((__nonnull__ (1, 2)));
-extern int mknod (__const char *__path, __mode_t __mode, __dev_t __dev)
-     __THROW __nonnull ((1));
-extern int symlink (__const char *__from, __const char *__to)
-     __THROW __nonnull ((1, 2)) __wur;
-extern int lchown (__const char *__file, __uid_t __owner, __gid_t __group)
-     __THROW __nonnull ((1)) __wur;
 #endif
 
-// よくわからないが、これが宣言されない。gcc -Eでは定義されているのに謎。
-
 #include <unistd.h>
-extern ssize_t readlink (__const char *__restrict __path,
-    char *__restrict __buf, size_t __len)
-     __attribute__ ((__nothrow__)) __attribute__ ((__nonnull__ (1, 2))) ;
-
-// これもそうだ。GNUのヘッダーって訳がわからない。
 
 #ifndef	NSIG
 # ifdef	_NSIG
@@ -60,33 +43,10 @@ extern ssize_t readlink (__const char *__restrict __path,
 # endif
 #endif
 
-#ifdef __LINUX__
-
-#include <linux/limits.h>
-/*
-#define __USE_POSIX
-#define __USE_XOPEN_EXTENDED
-#define __USE_POSIX199309
-#define __USE_UNIX98
-*/
+#include <limits.h>
 #include <signal.h>
-/*
-#undef __USE_POSIX
-#undef __USE_XOPEN_EXTENDED
-#undef __USE_POSIX199309
-#undef __USE_UNIX98
-*/
 #include <sys/wait.h>
 
-#else
-
-#include <signal.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-
-#endif
-
-
 #include <saphire_extra.h>             // 自作ライブラリ群
 #include <saphire_curses.h>
 #include <saphire_vector.h>
@@ -103,10 +63,6 @@ extern ssize_t readlink (__const char *__restrict __path,
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#if defined(__LINUX__)
-#include <linux/limits.h>
-#endif
-#include <limits.h>
 
 #if defined(S_ISTXT)
     #define S_ALLPERM (S_IRWXU|S_IRWXG|S_IRWXO|S_ISUID|S_ISGID|S_ISTXT)
@@ -128,9 +84,6 @@ extern BOOL gExitCode;              // 終了コード
 
 extern void (*gView)();             // 登録描写関数(関数を登録しておけばviewで実行される)
 
-volatile extern BOOL gSigInt;
-volatile extern BOOL gSigUser;
-
 void set_signal_mfiler();
 
 void view(BOOL cmdline_draw);                        // 全体の描写関数
@@ -167,23 +120,14 @@ void menu_start(char* menu_name);
 ///////////////////////////////////////////////////
 // isearch.c
 ///////////////////////////////////////////////////
-#if defined(HAVE_MIGEMO_H)
-#include "migemo.h"
-extern migemo* gMigemo;
-#endif
-
 extern BOOL gISearch;        // インクリメンタルサーチ中かどうか
-
 void isearch_init();         // インクリメンタルサーチ初期化
 void isearch_final();        // インクリメンタルサーチ解放
 
 void isearch_input(int meta, int key); // インクリメンタルサーチキー入力
 void isearch_view();                  // インクリメンタルサーチ描写
 
-extern BOOL gISearchExplore;           // エキスプローラー風インクリメンタルサーチ
 BOOL IsISearchExploreChar(int meta, int key);
-void isearch_explore_input(int meta, int key);
-void isearch_explore_view();
 BOOL IsISearchNULL();
 void ISearchClear();
 
@@ -193,6 +137,7 @@ void ISearchClear();
 extern BOOL gCmdLineActive;
 extern string_obj* gCmdLine;
 extern int gCmdLineCursor;
+
 #define kCmdLineMax 16000
 
 void cmdline_init();
@@ -218,8 +163,6 @@ void add_history(char* str);
 // cmdline_completion.c
 ///////////////////////////////////////////////////
 extern vector_obj* gCCandidate;
-extern vector_obj* gPrograms;             // プログラム名補完候補
-extern vector_obj* gEnvirons;             // 環境変数補完候補
 
 void cmdline_completion_init();
 void cmdline_completion_final();
@@ -230,7 +173,6 @@ void cmdline_completion_input(int meta, int key);
 void cmdline_completion_main();
 
 void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space);
-void cmdline_completion2(vector_obj* all_candidate, char* editing, BOOL add_space, int candidate_len);
 
 void cmdline_completion_file(char* editing_dir, char* editing_file, char* editing, int editing_position);
 void cmdline_completion_program(char* editing_dir, char* editing_file, char* editing, int editing_position);
@@ -245,7 +187,7 @@ void merr_msg(char* msg, ...);
 void msg_nonstop(char* msg, ...);
 int select_str(char* msg, char* str[], int len, int cancel);
 int select_str2(char* msg, char* str[], int len, int cancel);
-int input_box(char* msg, char* result, char* def_input, int def_cursor);
+int input_box(char* msg, char* result, int result_size, char* def_input, int def_cursor);
 
 ///////////////////////////////////////////////////
 // commands.c
