@@ -37,18 +37,18 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     
     mmvprintw(y+1, 5, "source");
     char tmp[PATH_MAX];
-    strcpy(tmp, spath);
+    strncpy(tmp, spath, PATH_MAX);
     if(S_ISDIR(stat_.st_mode)) {
-        strcat(tmp, "/");
+        strncat(tmp, "/", PATH_MAX);
     }
     else if(S_ISFIFO(stat_.st_mode)) {
-        strcat(tmp, "|");
+        strncat(tmp, "|", PATH_MAX);
     }
     else if(S_ISSOCK(stat_.st_mode)) {
-        strcat(tmp, "=");
+        strncat(tmp, "=", PATH_MAX);
     }
     else if(S_ISLNK(stat_.st_mode)) {
-        strcat(tmp, "@");
+        strncat(tmp, "@", PATH_MAX);
     }
     
     
@@ -66,18 +66,18 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     
     mmvprintw(y+6, 5, "distination");
     char tmp2[PATH_MAX];
-    strcpy(tmp2, dfile);
+    strncpy(tmp2, dfile, PATH_MAX);
     if(S_ISDIR(dfstat.st_mode)) {
-        strcat(tmp2, "/");
+        strncat(tmp2, "/", PATH_MAX);
     }
     else if(S_ISFIFO(dfstat.st_mode)) {
-        strcat(tmp, "|");
+        strncat(tmp, "|", PATH_MAX);
     }
     else if(S_ISSOCK(dfstat.st_mode)) {
-        strcat(tmp, "=");
+        strncat(tmp, "=", PATH_MAX);
     }
     else if(S_ISLNK(dfstat.st_mode)) {
-        strcat(tmp, "@");
+        strncat(tmp, "@", PATH_MAX);
     }
     
     mmvprintw(y+7, 5, "path: %s", tmp2);
@@ -122,7 +122,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     
     /// new file name check ///
     char new_fname[PATH_MAX];
-    strcpy(new_fname, "");
+    strncpy(new_fname, "", PATH_MAX);
     
     struct stat dstat;
     const int dlen = strlen(dpath);
@@ -137,7 +137,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
             while(p != dpath && *p != '/') {
                 p--;
             }
-            strcpy(new_fname, p+1);
+            strncpy(new_fname, p+1, PATH_MAX);
 
             dpath[p-dpath+1] = 0;
         }
@@ -147,7 +147,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
         while(p != dpath && *p != '/') {
             p--;
         }
-        strcpy(new_fname, p+1);
+        strncpy(new_fname, p+1, PATH_MAX);
 
         dpath[p-dpath+1] = 0;
     }
@@ -155,8 +155,8 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     /// add / ///
     char new_dpath[PATH_MAX];
     if(dpath[strlen(dpath) -1] != '/') {
-        strcpy(new_dpath, dpath);
-        strcat(new_dpath, "/");
+        strncpy(new_dpath, dpath, PATH_MAX);
+        strncat(new_dpath, "/", PATH_MAX);
 
         dpath = new_dpath;
     }
@@ -174,8 +174,8 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     /// illegal argument check ///
     char spath2[PATH_MAX];
 
-    strcpy(spath2, spath);
-    strcat(spath2, "/");
+    strncpy(spath2, spath, PATH_MAX);
+    strncat(spath2, "/", PATH_MAX);
         
     if(strstr(dpath, spath2) == dpath) {
         merr_msg("file_copy: destination err(%s)", dpath);
@@ -205,12 +205,12 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
             memcpy(sfname, spath + i + 1, len - i);
 
             /// get destination file name ///
-            strcpy(dfile, dpath);
-            strcat(dfile, sfname);
+            strncpy(dfile, dpath, PATH_MAX);
+            strncat(dfile, sfname, PATH_MAX);
         }
         else {
-            strcpy(dfile, dpath);
-            strcat(dfile, new_fname);
+            strncpy(dfile, dpath, PATH_MAX);
+            strncat(dfile, new_fname, PATH_MAX);
         }
 
         /// illegal argument check ///
@@ -222,7 +222,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
         if(S_ISDIR(stat_.st_mode)) {
             /// msg ///
             char buf[PATH_MAX+10];
-            sprintf(buf, "entering %s", spath);
+            snprintf(buf, PATH_MAX+10, "entering %s", spath);
             msg_nonstop("%s", buf);
 
             /// override ///
@@ -257,7 +257,7 @@ override_select_str:
                         };
 
                         char buf[256];
-                        sprintf(buf, "override? ");
+                        snprintf(buf, 256, "override? ");
                         int ret = select_str2(buf, (char**)str, 8, 7);
                         
                         gView = NULL;
@@ -284,14 +284,14 @@ override_select_str:
                             int result2;
                             BOOL exist_rename_file;
                             do {
-                                result2 = input_box("input name:", result, "", 0);
+                                result2 = input_box("input name:", result, 1024, "", 0);
                                 
                                 if(result2 == 1) {
                                     goto override_select_str;
                                 }
                                 
-                                strcpy(dfile_tmp, dpath);
-                                strcat(dfile_tmp, result);
+                                strncpy(dfile_tmp, dpath, PATH_MAX);
+                                strncat(dfile_tmp, result, PATH_MAX);
                                 
                                 exist_rename_file = access(dfile_tmp, F_OK) == 0;
                                 
@@ -300,7 +300,7 @@ override_select_str:
                                 }
                             } while(exist_rename_file);
                             
-                            strcpy(dfile,dfile_tmp);
+                            strncpy(dfile,dfile_tmp, PATH_MAX);
                             
                             }
                             break;
@@ -382,14 +382,14 @@ dir_copy:
                     {
                         char spath2[PATH_MAX];
 
-                        strcpy(spath2, spath);
-                        strcat(spath2, "/");
-                        strcat(spath2, entry->d_name);
+                        strncpy(spath2, spath, PATH_MAX);
+                        strncat(spath2, "/", PATH_MAX);
+                        strncat(spath2, entry->d_name, PATH_MAX);
 
                         char dfile2[PATH_MAX];
         
-                        strcpy(dfile2, dfile);
-                        strcat(dfile2, "/");
+                        strncpy(dfile2, dfile, PATH_MAX);
+                        strncat(dfile2, "/", PATH_MAX);
         
                         if(!file_copy(spath2, dfile2, move, preserve)) {
                             closedir(dir);
@@ -486,7 +486,7 @@ override_select_str2:
                     };
                     
                     char buf[256];
-                    sprintf(buf, "override? ");
+                    snprintf(buf, 256, "override? ");
                     int ret = select_str2(buf, (char**)str, 8, 7);
 
                     gView = NULL;
@@ -514,14 +514,14 @@ override_select_str2:
                         
                         char dfile_tmp[PATH_MAX];
                         do {
-                            result2 = input_box("input name:", result, "", 0);
+                            result2 = input_box("input name:", result, 1024, "", 0);
                             
                             if(result2 == 1) {
                                 goto override_select_str2;
                             }
                             
-                            strcpy(dfile_tmp, dpath);
-                            strcat(dfile_tmp, result);
+                            strncpy(dfile_tmp, dpath, PATH_MAX);
+                            strncat(dfile_tmp, result, PATH_MAX);
                             
                             exist_rename_file = access(dfile_tmp, F_OK) == 0;
                             if(exist_rename_file) {
@@ -529,7 +529,7 @@ override_select_str2:
                             }
                         } while(exist_rename_file);
                         
-                        strcpy(dfile, dfile_tmp);
+                        strncpy(dfile, dfile_tmp, PATH_MAX);
                         
                         }
                         break;
@@ -585,9 +585,9 @@ override_select_str2:
             /// msg ///
             char buf[PATH_MAX+10];
             if(move)
-                sprintf(buf, "moving %s", spath);
+                snprintf(buf, PATH_MAX+10, "moving %s", spath);
             else
-                sprintf(buf, "copying %s", spath);
+                snprintf(buf, PATH_MAX+10, "copying %s", spath);
             msg_nonstop("%s", buf);
 
             if(move) {
@@ -1078,7 +1078,7 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
                     };
                     
                     char buf[PATH_MAX+20];
-                    sprintf(buf, "remove write-protected file(%s)", path);
+                    snprintf(buf, PATH_MAX+20, "remove write-protected file(%s)", path);
                     int ret = select_str2(buf, (char**)str, 5, 4);
 
                     switch(ret) {
@@ -1110,7 +1110,7 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
             /// msg ///
             if(message) {
                 char buf[PATH_MAX+20];
-                sprintf(buf, "deleting %s", path);
+                snprintf(buf, PATH_MAX+20, "deleting %s", path);
                 msg_nonstop("%s", buf);
             }
 
@@ -1136,7 +1136,7 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
         /// directory ///
         else {
             char buf[PATH_MAX+20];
-            sprintf(buf, "entering %s", path);
+            snprintf(buf, PATH_MAX+20, "entering %s", path);
             msg_nonstop("%s", buf);
             
             DIR* dir = opendir(path);
@@ -1150,9 +1150,9 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
                     && strcmp(entry->d_name, "..") != 0)
                 {
                     char path2[PATH_MAX];
-                    strcpy(path2, path);
-                    strcat(path2, "/");
-                    strcat(path2, entry->d_name);
+                    strncpy(path2, path, PATH_MAX);
+                    strncat(path2, "/", PATH_MAX);
+                    strncat(path2, entry->d_name, PATH_MAX);
 
                     if(!file_remove(path2, no_ctrl_c, FALSE)) {
                         closedir(dir);
