@@ -21,7 +21,7 @@ void merr_msg(char* msg, ...)
         char msg2[1024];
         va_list args;
         va_start(args, msg);
-        vsprintf(msg2, msg, args);
+        vsnprintf(msg2, 1024, msg, args);
         va_end(args);
         
         const int maxy = mgetmaxy();
@@ -41,7 +41,7 @@ void merr_msg(char* msg, ...)
         char msg2[1024];
         va_list args;
         va_start(args, msg);
-        vsprintf(msg2, msg, args);
+        vsnprintf(msg2, 1024, msg, args);
         va_end(args);
 
         fprintf(stderr, "%s", msg2);
@@ -57,7 +57,7 @@ void msg_nonstop(char* msg, ...)
 
     va_list args;
     va_start(args, msg);
-    vsprintf(msg2, msg, args);
+    vsnprintf(msg2, 1024, msg, args);
     va_end(args);
 
     const int maxy = mgetmaxy();
@@ -185,7 +185,7 @@ void input_box_view()
     mmove(maxy -1, gInputBoxCursor);
 }
 
-int input_box(char* msg, char* result, char* def_input, int def_cursor)
+int input_box(char* msg, char* result, int result_size, char* def_input, int def_cursor)
 {
     gInputBoxMsg = msg;
     
@@ -329,7 +329,7 @@ int input_box(char* msg, char* result, char* def_input, int def_cursor)
             if(meta == 0 && !(key >= 0 && key <= 27)) {
                 char tmp[128];
 
-                sprintf(tmp, "%c", key);
+                snprintf(tmp, 128, "%c", key);
                 string_insert(gInputBoxInput, gInputBoxCursor, tmp);
                 gInputBoxCursor++;
             }
@@ -341,7 +341,7 @@ int input_box(char* msg, char* result, char* def_input, int def_cursor)
     int maxx = mgetmaxx();
     int maxy = mgetmaxy();
     
-    strcpy(result, string_c_str(gInputBoxInput));
+    strncpy(result, string_c_str(gInputBoxInput), result_size);
 
     mmove_immediately(maxy -2, 0);
 
