@@ -11,6 +11,7 @@
 #endif
 
 #if defined(HAVE_MIGEMO_H)
+#include <migemo.h>
 migemo* gMigemo;
 static regex_t* gReg;
 hash_obj* gMigemoCache; // 一文字だけの正規表現のクェリーは重いのでキャッシュする
@@ -23,9 +24,7 @@ static string_obj* gInputFileName;      // 入力された文字列
 ///////////////////////////////////////////////////
 BOOL gISearch = FALSE;                  // 現在インクリメンタルサーチ中かどうか
 BOOL gISearchPartMatch = FALSE;         // 現在インクリメンタルサーチパートマッチ中かどうか
-BOOL gISearchExplore = FALSE;           // エキスプローラー風インクリメンタルサーチ
 BOOL gNoPartMatchClear = FALSE;         // ISearchClarでgISearchPartMatchをクリアするかどうか
-BOOL gISearchOption1 = TRUE;            // 先頭インクリメンタルサーチが失敗したら部分一致インクリメンタルサーチするオプション
 
 // その文字がエクスプローラー風インクリメンタルサーチで使うものかどうか
 BOOL IsISearchExploreChar(int meta, int key)
@@ -63,10 +62,6 @@ static BOOL is_isearch_char(int key)
 {
     return key == 9 || (key >= ' ' && key <= '~')
                 && key != '\\';
-//                && key != '/'
-//                && key != '~'
-//                && key != ' '
-//                && key != '?';
 }
 
 /// 後ろにマッチするファイル名にカーソルを移動 ///
@@ -337,69 +332,69 @@ static void migemo_init()
     char migemodir[PATH_MAX];
     gMigemo = migemo_open(NULL);
 
-    sprintf(migemodir,"%s", SYSTEM_MIGEMODIR);
+    snprintf(migemodir, PATH_MAX,"%s", SYSTEM_MIGEMODIR);
 
     if(gKanjiCode == kUtf8) {
-        sprintf(buf, "%s/utf-8/migemo-dict", migemodir);
+        snprintf(buf, PATH_MAX, "%s/utf-8/migemo-dict", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_MIGEMO, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/utf-8/roma2hira.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/utf-8/roma2hira.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_ROMA2HIRA, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/utf-8/hira2kata.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/utf-8/hira2kata.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_HIRA2KATA, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/utf-8/han2zen.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/utf-8/han2zen.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_HAN2ZEN, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
     }
     else if(gKanjiCode == kEucjp) {
-        sprintf(buf, "%s/euc-jp/migemo-dict", migemodir);
+        snprintf(buf, PATH_MAX, "%s/euc-jp/migemo-dict", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_MIGEMO, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/euc-jp/roma2hira.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/euc-jp/roma2hira.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_ROMA2HIRA, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/euc-jp/hira2kata.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/euc-jp/hira2kata.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_HIRA2KATA, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/euc-jp/han2zen.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/euc-jp/han2zen.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_HAN2ZEN, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
     }
     else {
-        sprintf(buf, "%s/cp932/migemo-dict", migemodir);
+        snprintf(buf, PATH_MAX, "%s/cp932/migemo-dict", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_MIGEMO, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/cp932/roma2hira.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/cp932/roma2hira.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_ROMA2HIRA, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/cp932/hira2kata.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/cp932/hira2kata.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_HIRA2KATA, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
         }
-        sprintf(buf, "%s/cp932/han2zen.dat", migemodir);
+        snprintf(buf, PATH_MAX, "%s/cp932/han2zen.dat", migemodir);
         if(migemo_load(gMigemo, MIGEMO_DICTID_HAN2ZEN, buf) == MIGEMO_DICTID_INVALID) {
             fprintf(stderr, "%s is not found\n", buf);
             exit(1);
@@ -433,7 +428,7 @@ void isearch_final()
     if(gReg && hash_key(gMigemoCache, gReg) == NULL) onig_free(gReg);
     gReg = NULL;
     hash_it* it = hash_loop_begin(gMigemoCache);
-    while(!it) {
+    while(it != NULL) {
         regex_t* reg  = hash_loop_item(it);
         onig_free(reg);
 
@@ -461,7 +456,7 @@ void isearch_input(int meta, int key)
 #endif
     }
     else if(key == 14 || key == KEY_DOWN) {
-        if(gISearchOption1 && !gISearchPartMatch) {
+        if(!gISearchPartMatch) {
             gISearchPartMatch = TRUE;
             match_next(filer_dir(adir())->mCursor+1);
             gISearchPartMatch = FALSE;
@@ -471,7 +466,7 @@ void isearch_input(int meta, int key)
         }
     }
     else if(key == 16 || key == KEY_UP) {
-        if(gISearchOption1 && !gISearchPartMatch) {
+        if(!gISearchPartMatch) {
             gISearchPartMatch = TRUE;
             match_back(filer_dir(adir())->mCursor-1);
             gISearchPartMatch = FALSE;
@@ -483,7 +478,7 @@ void isearch_input(int meta, int key)
     else if(key == ' ') {
         filer_toggle_mark(adir(), filer_dir(adir())->mCursor);
 
-        if(gISearchOption1 && !gISearchPartMatch) {
+        if(!gISearchPartMatch) {
             gISearchPartMatch = TRUE;
             match_next(filer_dir(adir())->mCursor+1);
             gISearchPartMatch = FALSE;
@@ -522,7 +517,7 @@ void isearch_input(int meta, int key)
         }
 #endif
 
-        if(gISearchOption1 && !gISearchPartMatch) {
+        if(!gISearchPartMatch) {
             if(!match_next(0)) {
                 gISearchPartMatch = TRUE;
 
@@ -561,99 +556,6 @@ void isearch_input(int meta, int key)
     }
 }
 
-void isearch_explore_input(int meta, int key)
-{
-    if(meta == 1 && key == KEY_UP || key == KEY_F(15) || meta == 1 && key == 16) {
-        if(gISearchOption1 && !gISearchPartMatch) {
-            gISearchPartMatch = TRUE;
-            match_back(filer_dir(adir())->mCursor-1);
-            gISearchPartMatch = FALSE;
-        }
-        else {
-            match_back(filer_dir(adir())->mCursor-1);
-        }
-    }
-    else if(meta == 1 && key == KEY_DOWN || key == KEY_F(16) || meta == 1 && key == 14) {
-        if(gISearchOption1 && !gISearchPartMatch) {
-            gISearchPartMatch = TRUE;
-            match_next(filer_dir(adir())->mCursor+1);
-            gISearchPartMatch = FALSE;
-        }
-        else {
-            match_next(filer_dir(adir())->mCursor+1);
-        }
-    }
-    else if(key == ' ') {
-        filer_toggle_mark(adir(), filer_dir(adir())->mCursor);
-        if(gISearchOption1 && !gISearchPartMatch) {
-            gISearchPartMatch = TRUE;
-            match_next(filer_dir(adir())->mCursor+1);
-            gISearchPartMatch = FALSE;
-        }
-        else {
-            match_next(filer_dir(adir())->mCursor+1);
-        }
-    }
-    else {
-        string_push_back2(gInputFileName, (char)key);
-
-#if defined(HAVE_MIGEMO_H)
-        if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
-            onig_free(gReg);
-            gReg = NULL;
-        }
-        else {
-            gReg = NULL;
-        }
-#endif
-
-        if(gISearchOption1 && !gISearchPartMatch) {
-            if(!match_next(0)) {
-                gISearchPartMatch = TRUE;
-
-                if(!match_next(0)) {
-                    string_put(gInputFileName, "");
-                    string_push_back2(gInputFileName, (char)key);
-
-#if defined(HAVE_MIGEMO_H)
-                    if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
-                        onig_free(gReg);
-                        gReg = NULL;
-                    }
-                    else {
-                        gReg = NULL;
-                    }
-#endif
-                    if(!match_next(0)) {
-                        string_put(gInputFileName, "");
-                    }
-                }
-
-                gISearchPartMatch = FALSE;
-            }
-        }
-        else {
-            if(!match_next(0)) {
-                string_put(gInputFileName, "");
-                string_push_back2(gInputFileName, (char)key);
-
-#if defined(HAVE_MIGEMO_H)
-                if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
-                    onig_free(gReg);
-                    gReg = NULL;
-                }
-                else {
-                    gReg = NULL;
-                }
-#endif
-                if(!match_next(0)) {
-                    string_put(gInputFileName, "");
-                }
-            }
-        }
-    }
-}
-
 ///////////////////////////////////////////////////
 // インクリメンタルサーチ描写
 ///////////////////////////////////////////////////
@@ -683,28 +585,3 @@ void isearch_view()
     mprintw(buf);
 }
 
-void isearch_explore_view()
-{
-    const int maxx = mgetmaxx();
-
-    if(gISearchPartMatch) 
-        mprintw(" //");
-    else
-        mprintw(" /");
-
-    char buf[1024];
-    char* str = string_c_str(gInputFileName);
-    const int len = strlen(str);
-    int i;
-    for(i=0; i<maxx-35; i++) {
-        if(i<len) {
-            buf[i] = str[i];
-        }
-        else {
-            buf[i] = ' ';
-        }
-    }
-    buf[i] = 0;
-    mprintw(buf);
-}
-
