@@ -32,7 +32,7 @@
 
 #ifdef __LINUX__
 
-#include <linux/limits.h>
+#include <limits.h>
 /*
 #define __USE_POSIX
 #define __USE_XOPEN_EXTENDED
@@ -55,12 +55,13 @@
 #include <sys/wait.h>
 
 #endif
-
+/*
 #if !defined(__DARWIN__)
 extern int kill (__pid_t __pid, int __sig) __THROW;
 extern int setenv(const char *name, const char *value, int overwrite);
 extern void srandom (unsigned int __seed) __THROW;
 #endif
+*/
 
 BOOL gMainLoop = FALSE;
 void (*gView)() = NULL;          // 登録描写関数
@@ -96,20 +97,6 @@ static void input(int meta, int key)
     else if(gISearch) {
         isearch_input(meta, key);
     }
-    /// エキスプローラー風インクリメンタルサーチ ///
-    else if(gISearchExplore && IsISearchExploreChar(meta, key)) {
-        isearch_explore_input(meta, key);
-    }
-    /// エキスプローラー風インクリメンタルサーチ 上下キーとスペースキー ///
-    else if(gISearchExplore && !IsISearchNULL() 
-        && (meta == 0 && key == ' '
-            || meta == 1 && (key == 14 || key == 16)
-            || meta == 1 && (key == KEY_UP || key == KEY_DOWN)
-            || meta == 0 && (key == KEY_F(15) || key == KEY_F(16))
-            ))
-    {
-        isearch_explore_input(meta, key);
-    }
     else {
         /// ファイラー ///
         filer_input(meta, key);
@@ -131,7 +118,7 @@ static void job_view()
 
         const int x = (maxx/size)*i;
         char buf[BUFSIZ];
-        sprintf(buf, "[%d]%s", i+1, title);
+        snprintf(buf, BUFSIZ, "[%d]%s", i+1, title);
         char buf2[BUFSIZ];
         
         str_cut(kUtf8, buf, maxx/size, buf2, BUFSIZ);
@@ -235,51 +222,6 @@ static void read_rc_file_compiled()
     }
 }
 
-static void read_rc_file()
-{
-    char rc_fname[256];
-
-    sprintf(rc_fname, "%s/mfiler3.ksh", gHomeDir);
-
-    if(access(rc_fname, R_OK) == 0) {
-        sRFd* pipein = sRFd_new(STDIN_FILENO);
-        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
-        int rcode = saphire_load(rc_fname
-            , pipeout, pipein, STDERR_FILENO);
-        saphire_sweep();
-        sRFd_delete(pipein);
-        sWFd_flash(pipeout);
-        sWFd_delete(pipeout);
-        if(rcode < 0) {
-            fprintf(stderr, "%s\n", string_c_str(gErrMsg));
-            exit(1);
-        }
-    }
-    else {
-        sprintf(rc_fname,"%s/mfiler3.ksh", SYSCONFDIR);
-
-        if(access(rc_fname, R_OK) == 0) {
-            sRFd* pipein = sRFd_new(STDIN_FILENO);
-            sWFd* pipeout = sWFd_new(STDOUT_FILENO);
-            int rcode = saphire_load(rc_fname
-                , pipeout, pipein, STDERR_FILENO);
-            saphire_sweep();
-            sRFd_delete(pipein);
-            sWFd_flash(pipeout);
-            sWFd_delete(pipeout);
-
-            if(rcode < 0) {
-                fprintf(stderr, "%s\n", string_c_str(gErrMsg));
-                exit(1);
-            }
-        }
-        else {
-            fprintf(stderr, "can't find %s/mfiler3.ksh file\n", SYSCONFDIR);
-            exit(1);
-        }
-    }
-}
-
 ///////////////////////////////////////////////////
 // exit時に実行される関数
 ///////////////////////////////////////////////////
@@ -430,7 +372,7 @@ static void main_arg_e(char* send_cmd, int pid)
 {
     /// ソケットを送る ///
     char soc_name[PATH_MAX];
-    sprintf(soc_name, "%s/socket%d", gTempDir, pid);
+    snprintf(soc_name, PATH_MAX, "%s/socket%d", gTempDir, pid);
 
     if(access(soc_name, F_OK) == 0) {
         /// コマンドをソケットで送る ///
@@ -451,7 +393,7 @@ static void main_arg_e(char* send_cmd, int pid)
         
         /// コマンド結果をパイプで受けとる ///
         char pipe_name[PATH_MAX];
-        sprintf(pipe_name, "%s/pipe_%d", gTempDir, pid);
+        snprintf(pipe_name, PATH_MAX, "%s/pipe_%d", gTempDir, pid);
 
         if(access(pipe_name, F_OK) == 0) {
             int pipe = open(pipe_name, O_RDONLY);
@@ -543,343 +485,343 @@ static void set_mfenv()
 
     char buf[128];
 
-    sprintf(buf, "%d", KEY_UP);
+    snprintf(buf, 128, "%d", KEY_UP);
     setenv("key_up", buf, 1);
-    sprintf(buf, "%d", KEY_RIGHT);
+    snprintf(buf, 128, "%d", KEY_RIGHT);
     setenv("key_right", buf, 1);
-    sprintf(buf, "%d", KEY_DOWN);
+    snprintf(buf, 128, "%d", KEY_DOWN);
     setenv("key_down", buf, 1);
-    sprintf(buf, "%d", KEY_LEFT);
+    snprintf(buf, 128, "%d", KEY_LEFT);
     setenv("key_left", buf, 1);
-    sprintf(buf, "%d", KEY_IC);
+    snprintf(buf, 128, "%d", KEY_IC);
     setenv("key_insert", buf, 1);
-    sprintf(buf, "%d", KEY_DC);
+    snprintf(buf, 128, "%d", KEY_DC);
     setenv("key_delete", buf, 1);
-    sprintf(buf, "%d", KEY_HOME);
+    snprintf(buf, 128, "%d", KEY_HOME);
     setenv("key_home", buf, 1);
-    sprintf(buf, "%d", KEY_END);
+    snprintf(buf, 128, "%d", KEY_END);
     setenv("key_end", buf, 1);
-    sprintf(buf, "%d", KEY_PPAGE);
+    snprintf(buf, 128, "%d", KEY_PPAGE);
     setenv("key_pageup", buf, 1);
-    sprintf(buf, "%d", KEY_NPAGE);
+    snprintf(buf, 128, "%d", KEY_NPAGE);
     setenv("key_pagedown", buf, 1);
-    sprintf(buf, "%d", KEY_F(13));
+    snprintf(buf, 128, "%d", KEY_F(13));
     setenv("key_meta_left", buf, 1);
-    sprintf(buf, "%d", KEY_F(14));
+    snprintf(buf,128, "%d", KEY_F(14));
     setenv("key_meta_right", buf, 1);
-    sprintf(buf, "%d", KEY_F(15));
+    snprintf(buf,128, "%d", KEY_F(15));
     setenv("key_meta_up", buf, 1);
-    sprintf(buf, "%d", KEY_F(16));
+    snprintf(buf,128, "%d", KEY_F(16));
     setenv("key_meta_down", buf, 1);
-    sprintf(buf, "%d", KEY_F(17));
+    snprintf(buf,128, "%d", KEY_F(17));
     setenv("key_ctrl_left", buf, 1);
-    sprintf(buf, "%d", KEY_F(18));
+    snprintf(buf,128, "%d", KEY_F(18));
     setenv("key_ctrl_right", buf, 1);
-    sprintf(buf, "%d", KEY_F(19));
+    snprintf(buf,128, "%d", KEY_F(19));
     setenv("key_ctrl_up", buf, 1);
-    sprintf(buf, "%d", KEY_F(20));
+    snprintf(buf,128, "%d", KEY_F(20));
     setenv("key_ctrl_down", buf, 1);
-    sprintf(buf, "%d", KEY_F(21));
+    snprintf(buf,128, "%d", KEY_F(21));
     setenv("key_ctrl_delete", buf, 1);
-    sprintf(buf, "%d", 10);
+    snprintf(buf,128, "%d", 10);
     setenv("key_enter", buf, 1);
-    sprintf(buf, "%d", KEY_BACKSPACE);
+    snprintf(buf,128, "%d", KEY_BACKSPACE);
     setenv("key_backspace", buf, 1);
-    sprintf(buf, "%d", KEY_F(1));
+    snprintf(buf,128, "%d", KEY_F(1));
     setenv("key_f1", buf, 1);
-    sprintf(buf, "%d", KEY_F(2));
+    snprintf(buf,128, "%d", KEY_F(2));
     setenv("key_f2", buf, 1);
-    sprintf(buf, "%d", KEY_F(3));
+    snprintf(buf,128, "%d", KEY_F(3));
     setenv("key_f3", buf, 1);
-    sprintf(buf, "%d", KEY_F(4));
+    snprintf(buf,128, "%d", KEY_F(4));
     setenv("key_f4", buf, 1);
-    sprintf(buf, "%d", KEY_F(5));
+    snprintf(buf,128, "%d", KEY_F(5));
     setenv("key_f5", buf, 1);
-    sprintf(buf, "%d", KEY_F(6));
+    snprintf(buf,128, "%d", KEY_F(6));
     setenv("key_f6", buf, 1);
-    sprintf(buf, "%d", KEY_F(7));
+    snprintf(buf,128, "%d", KEY_F(7));
     setenv("key_f7", buf, 1);
-    sprintf(buf, "%d", KEY_F(8));
+    snprintf(buf,128, "%d", KEY_F(8));
     setenv("key_f8", buf, 1);
-    sprintf(buf, "%d", KEY_F(9));
+    snprintf(buf,128, "%d", KEY_F(9));
     setenv("key_f9", buf, 1);
-    sprintf(buf, "%d", KEY_F(10));
+    snprintf(buf,128, "%d", KEY_F(10));
     setenv("key_f10", buf, 1);
-    sprintf(buf, "%d", KEY_F(11));
+    snprintf(buf,128, "%d", KEY_F(11));
     setenv("key_f11", buf, 1);
-    sprintf(buf, "%d", KEY_F(12));
+    snprintf(buf,128, "%d", KEY_F(12));
     setenv("key_f12", buf, 1);
-    sprintf(buf, "%d", 'a');
+    snprintf(buf,128, "%d", 'a');
     setenv("key_a", buf, 1);
-    sprintf(buf, "%d", 'b');
+    snprintf(buf,128, "%d", 'b');
     setenv("key_b", buf, 1);
-    sprintf(buf, "%d", 'c');
+    snprintf(buf,128, "%d", 'c');
     setenv("key_c", buf, 1);
-    sprintf(buf, "%d", 'd');
+    snprintf(buf,128, "%d", 'd');
     setenv("key_d", buf, 1);
-    sprintf(buf, "%d", 'e');
+    snprintf(buf,128, "%d", 'e');
     setenv("key_e", buf, 1);
-    sprintf(buf, "%d", 'f');
+    snprintf(buf,128, "%d", 'f');
     setenv("key_f", buf, 1);
-    sprintf(buf, "%d", 'g');
+    snprintf(buf,128, "%d", 'g');
     setenv("key_g", buf, 1);
-    sprintf(buf, "%d", 'h');
+    snprintf(buf,128, "%d", 'h');
     setenv("key_h", buf, 1);
-    sprintf(buf, "%d", 'i');
+    snprintf(buf,128, "%d", 'i');
     setenv("key_i", buf, 1);
-    sprintf(buf, "%d", 'j');
+    snprintf(buf,128, "%d", 'j');
     setenv("key_j", buf, 1);
-    sprintf(buf, "%d", 'k');
+    snprintf(buf,128, "%d", 'k');
     setenv("key_k", buf, 1);
-    sprintf(buf, "%d", 'l');
+    snprintf(buf,128, "%d", 'l');
     setenv("key_l", buf, 1);
-    sprintf(buf, "%d", 'm');
+    snprintf(buf,128, "%d", 'm');
     setenv("key_m", buf, 1);
-    sprintf(buf, "%d", 'n');
+    snprintf(buf,128, "%d", 'n');
     setenv("key_n", buf, 1);
-    sprintf(buf, "%d", 'o');
+    snprintf(buf,128, "%d", 'o');
     setenv("key_o", buf, 1);
-    sprintf(buf, "%d", 'p');
+    snprintf(buf,128, "%d", 'p');
     setenv("key_p", buf, 1);
-    sprintf(buf, "%d", 'q');
+    snprintf(buf,128, "%d", 'q');
     setenv("key_q", buf, 1);
-    sprintf(buf, "%d", 'r');
+    snprintf(buf,128, "%d", 'r');
     setenv("key_r", buf, 1);
-    sprintf(buf, "%d", 's');
+    snprintf(buf,128, "%d", 's');
     setenv("key_s", buf, 1);
-    sprintf(buf, "%d", 't');
+    snprintf(buf,128, "%d", 't');
     setenv("key_t", buf, 1);
-    sprintf(buf, "%d", 'u');
+    snprintf(buf,128, "%d", 'u');
     setenv("key_u", buf, 1);
-    sprintf(buf, "%d", 'v');
+    snprintf(buf,128, "%d", 'v');
     setenv("key_v", buf, 1);
-    sprintf(buf, "%d", 'w');
+    snprintf(buf,128, "%d", 'w');
     setenv("key_w", buf, 1);
-    sprintf(buf, "%d", 'x');
+    snprintf(buf,128, "%d", 'x');
     setenv("key_x", buf, 1);
-    sprintf(buf, "%d", 'y');
+    snprintf(buf,128, "%d", 'y');
     setenv("key_y", buf, 1);
-    sprintf(buf, "%d", 'z');
+    snprintf(buf,128, "%d", 'z');
     setenv("key_z", buf, 1);
-    sprintf(buf, "%d", 'A');
+    snprintf(buf,128, "%d", 'A');
     setenv("key_A", buf, 1);
-    sprintf(buf, "%d", 'B');
+    snprintf(buf,128, "%d", 'B');
     setenv("key_B", buf, 1);
-    sprintf(buf, "%d", 'C');
+    snprintf(buf,128, "%d", 'C');
     setenv("key_C", buf, 1);
-    sprintf(buf, "%d", 'D');
+    snprintf(buf,128, "%d", 'D');
     setenv("key_D", buf, 1);
-    sprintf(buf, "%d", 'E');
+    snprintf(buf,128, "%d", 'E');
     setenv("key_E", buf, 1);
-    sprintf(buf, "%d", 'F');
+    snprintf(buf,128, "%d", 'F');
     setenv("key_F", buf, 1);
-    sprintf(buf, "%d", 'G');
+    snprintf(buf,128, "%d", 'G');
     setenv("key_G", buf, 1);
-    sprintf(buf, "%d", 'H');
+    snprintf(buf,128, "%d", 'H');
     setenv("key_H", buf, 1);
-    sprintf(buf, "%d", 'I');
+    snprintf(buf,128, "%d", 'I');
     setenv("key_I", buf, 1);
-    sprintf(buf, "%d", 'J');
+    snprintf(buf,128, "%d", 'J');
     setenv("key_J", buf, 1);
-    sprintf(buf, "%d", 'K');
+    snprintf(buf,128, "%d", 'K');
     setenv("key_K", buf, 1);
-    sprintf(buf, "%d", 'L');
+    snprintf(buf,128, "%d", 'L');
     setenv("key_L", buf, 1);
-    sprintf(buf, "%d", 'M');
+    snprintf(buf,128, "%d", 'M');
     setenv("key_M", buf, 1);
-    sprintf(buf, "%d", 'N');
+    snprintf(buf,128, "%d", 'N');
     setenv("key_N", buf, 1);
-    sprintf(buf, "%d", 'O');
+    snprintf(buf,128, "%d", 'O');
     setenv("key_O", buf, 1);
-    sprintf(buf, "%d", 'P');
+    snprintf(buf,128, "%d", 'P');
     setenv("key_P", buf, 1);
-    sprintf(buf, "%d", 'Q');
+    snprintf(buf,128, "%d", 'Q');
     setenv("key_Q", buf, 1);
-    sprintf(buf, "%d", 'R');
+    snprintf(buf,128, "%d", 'R');
     setenv("key_R", buf, 1);
-    sprintf(buf, "%d", 'S');
+    snprintf(buf,128, "%d", 'S');
     setenv("key_S", buf, 1);
-    sprintf(buf, "%d", 'T');
+    snprintf(buf,128, "%d", 'T');
     setenv("key_T", buf, 1);
-    sprintf(buf, "%d", 'U');
+    snprintf(buf,128, "%d", 'U');
     setenv("key_U", buf, 1);
-    sprintf(buf, "%d", 'V');
+    snprintf(buf,128, "%d", 'V');
     setenv("key_V", buf, 1);
-    sprintf(buf, "%d", 'W');
+    snprintf(buf,128, "%d", 'W');
     setenv("key_W", buf, 1);
-    sprintf(buf, "%d", 'X');
+    snprintf(buf,128, "%d", 'X');
     setenv("key_X", buf, 1);
-    sprintf(buf, "%d", 'Y');
+    snprintf(buf,128, "%d", 'Y');
     setenv("key_Y", buf, 1);
-    sprintf(buf, "%d", 'Z');
+    snprintf(buf,128, "%d", 'Z');
     setenv("key_Z", buf, 1);
-    sprintf(buf, "%d", 32);
+    snprintf(buf,128, "%d", 32);
     setenv("key_space", buf, 1);
-    sprintf(buf, "%d", 0);
+    snprintf(buf,128, "%d", 0);
     setenv("key_ctrl_space", buf, 1);
-    sprintf(buf, "%d", 1);
+    snprintf(buf,128, "%d", 1);
     setenv("key_ctrl_a", buf, 1);
-    sprintf(buf, "%d", 2);
+    snprintf(buf,128, "%d", 2);
     setenv("key_ctrl_b", buf, 1);
-    sprintf(buf, "%d", 3);
+    snprintf(buf,128, "%d", 3);
     setenv("key_ctrl_c", buf, 1);
-    sprintf(buf, "%d", 4);
+    snprintf(buf,128, "%d", 4);
     setenv("key_ctrl_d", buf, 1);
-    sprintf(buf, "%d", 5);
+    snprintf(buf,128, "%d", 5);
     setenv("key_ctrl_e", buf, 1);
-    sprintf(buf, "%d", 6);
+    snprintf(buf,128, "%d", 6);
     setenv("key_ctrl_f", buf, 1);
-    sprintf(buf, "%d", 7);
+    snprintf(buf,128, "%d", 7);
     setenv("key_ctrl_g", buf, 1);
-    sprintf(buf, "%d", 8);
+    snprintf(buf,128, "%d", 8);
     setenv("key_ctrl_h", buf, 1);
-    sprintf(buf, "%d", 9);
+    snprintf(buf,128, "%d", 9);
     setenv("key_ctrl_i", buf, 1);
-    sprintf(buf, "%d", 10);
+    snprintf(buf,128, "%d", 10);
     setenv("key_ctrl_j", buf, 1);
-    sprintf(buf, "%d", 11);
+    snprintf(buf,128, "%d", 11);
     setenv("key_ctrl_k", buf, 1);
-    sprintf(buf, "%d", 12);
+    snprintf(buf,128, "%d", 12);
     setenv("key_ctrl_l", buf, 1);
-    sprintf(buf, "%d", 13);
+    snprintf(buf,128, "%d", 13);
     setenv("key_ctrl_m", buf, 1);
-    sprintf(buf, "%d", 14);
+    snprintf(buf,128, "%d", 14);
     setenv("key_ctrl_n", buf, 1);
-    sprintf(buf, "%d", 15);
+    snprintf(buf,128, "%d", 15);
     setenv("key_ctrl_o", buf, 1);
-    sprintf(buf, "%d", 16);
+    snprintf(buf,128, "%d", 16);
     setenv("key_ctrl_p", buf, 1);
-    sprintf(buf, "%d", 17);
+    snprintf(buf,128, "%d", 17);
     setenv("key_ctrl_q", buf, 1);
-    sprintf(buf, "%d", 18);
+    snprintf(buf,128, "%d", 18);
     setenv("key_ctrl_r", buf, 1);
-    sprintf(buf, "%d", 19);
+    snprintf(buf,128, "%d", 19);
     setenv("key_ctrl_s", buf, 1);
-    sprintf(buf, "%d", 20);
+    snprintf(buf,128, "%d", 20);
     setenv("key_ctrl_t", buf, 1);
-    sprintf(buf, "%d", 21);
+    snprintf(buf,128, "%d", 21);
     setenv("key_ctrl_u", buf, 1);
-    sprintf(buf, "%d", 22);
+    snprintf(buf,128, "%d", 22);
     setenv("key_ctrl_v", buf, 1);
-    sprintf(buf, "%d", 23);
+    snprintf(buf,128, "%d", 23);
     setenv("key_ctrl_w", buf, 1);
-    sprintf(buf, "%d", 24);
+    snprintf(buf,128, "%d", 24);
     setenv("key_ctrl_x", buf, 1);
-    sprintf(buf, "%d", 25);
+    snprintf(buf,128, "%d", 25);
     setenv("key_ctrl_y", buf, 1);
-    sprintf(buf, "%d", 26);
+    snprintf(buf,128, "%d", 26);
     setenv("key_ctrl_z", buf, 1);
-    sprintf(buf, "%d", 27);
+    snprintf(buf,128, "%d", 27);
     setenv("key_escape", buf, 1);
-    sprintf(buf, "%d", 9);
+    snprintf(buf,128, "%d", 9);
     setenv("key_tab", buf, 1);
-    sprintf(buf, "%d", '0');
+    snprintf(buf,128, "%d", '0');
     setenv("key_0", buf, 1);
-    sprintf(buf, "%d", '1');
+    snprintf(buf,128, "%d", '1');
     setenv("key_1", buf, 1);
-    sprintf(buf, "%d", '2');
+    snprintf(buf,128, "%d", '2');
     setenv("key_2", buf, 1);
-    sprintf(buf, "%d", '3');
+    snprintf(buf,128, "%d", '3');
     setenv("key_3", buf, 1);
-    sprintf(buf, "%d", '4');
+    snprintf(buf,128, "%d", '4');
     setenv("key_4", buf, 1);
-    sprintf(buf, "%d", '5');
+    snprintf(buf,128, "%d", '5');
     setenv("key_5", buf, 1);
-    sprintf(buf, "%d", '6');
+    snprintf(buf,128, "%d", '6');
     setenv("key_6", buf, 1);
-    sprintf(buf, "%d", '7');
+    snprintf(buf,128, "%d", '7');
     setenv("key_7", buf, 1);
-    sprintf(buf, "%d", '8');
+    snprintf(buf,128, "%d", '8');
     setenv("key_8", buf, 1);
-    sprintf(buf, "%d", '9');
+    snprintf(buf,128, "%d", '9');
     setenv("key_9", buf, 1);
-    sprintf(buf, "%d", '!');
+    snprintf(buf,128, "%d", '!');
     setenv("key_exclam", buf, 1);
-    sprintf(buf, "%d", '"');
+    snprintf(buf,128, "%d", '"');
     setenv("key_dquote", buf, 1);
-    sprintf(buf, "%d", '#');
+    snprintf(buf,128, "%d", '#');
     setenv("key_sharp", buf, 1);
-    sprintf(buf, "%d", '$');
+    snprintf(buf,128, "%d", '$');
     setenv("key_dollar", buf, 1);
-    sprintf(buf, "%d", '%');
+    snprintf(buf,128, "%d", '%');
     setenv("key_percent", buf, 1);
-    sprintf(buf, "%d", '&');
+    snprintf(buf,128, "%d", '&');
     setenv("key_and", buf, 1);
-    sprintf(buf, "%d", '\'');
+    snprintf(buf,128, "%d", '\'');
     setenv("key_squote", buf, 1);
-    sprintf(buf, "%d", '(');
+    snprintf(buf,128, "%d", '(');
     setenv("key_lparen", buf, 1);
-    sprintf(buf, "%d", ')');
+    snprintf(buf,128, "%d", ')');
     setenv("key_rparen", buf, 1);
-    sprintf(buf, "%d", '~');
+    snprintf(buf,128, "%d", '~');
     setenv("key_tilda", buf, 1);
-    sprintf(buf, "%d", '=');
+    snprintf(buf,128, "%d", '=');
     setenv("key_equal", buf, 1);
-    sprintf(buf, "%d", '-');
+    snprintf(buf,128, "%d", '-');
     setenv("key_minus", buf, 1);
-    sprintf(buf, "%d", '^');
+    snprintf(buf,128, "%d", '^');
     setenv("key_cup", buf, 1);
-    sprintf(buf, "%d", '|');
+    snprintf(buf,128, "%d", '|');
     setenv("key_vbar", buf, 1);
-    sprintf(buf, "%d", '\\');
+    snprintf(buf,128, "%d", '\\');
     setenv("key_backslash", buf, 1);
-    sprintf(buf, "%d", '@');
+    snprintf(buf,128, "%d", '@');
     setenv("key_atmark", buf, 1);
-    sprintf(buf, "%d", '`');
+    snprintf(buf,128, "%d", '`');
     setenv("key_bapostrophe", buf, 1);
-    sprintf(buf, "%d", '{');
+    snprintf(buf,128, "%d", '{');
     setenv("key_lcurly", buf, 1);
-    sprintf(buf, "%d", '[');
+    snprintf(buf,128, "%d", '[');
     setenv("key_lbrack", buf, 1);
-    sprintf(buf, "%d", '+');
+    snprintf(buf,128, "%d", '+');
     setenv("key_plus", buf, 1);
-    sprintf(buf, "%d", ';');
+    snprintf(buf,128, "%d", ';');
     setenv("key_semicolon", buf, 1);
-    sprintf(buf, "%d", '*');
+    snprintf(buf,128, "%d", '*');
     setenv("key_star", buf, 1);
-    sprintf(buf, "%d", ':');
+    snprintf(buf,128, "%d", ':');
     setenv("key_colon", buf, 1);
-    sprintf(buf, "%d", '}');
+    snprintf(buf,128, "%d", '}');
     setenv("key_rcurly", buf, 1);
-    sprintf(buf, "%d", ']');
+    snprintf(buf,128, "%d", ']');
     setenv("key_rbrack", buf, 1);
-    sprintf(buf, "%d", '<');
+    snprintf(buf,128, "%d", '<');
     setenv("key_lss", buf, 1);
-    sprintf(buf, "%d", ',');
+    snprintf(buf,128, "%d", ',');
     setenv("key_comma", buf, 1);
-    sprintf(buf, "%d", '>');
+    snprintf(buf,128, "%d", '>');
     setenv("key_gtr", buf, 1);
-    sprintf(buf, "%d", '.');
+    snprintf(buf,128, "%d", '.');
     setenv("key_dot", buf, 1);
-    sprintf(buf, "%d", '/');
+    snprintf(buf,128, "%d", '/');
     setenv("key_slash", buf, 1);
-    sprintf(buf, "%d", '?');
+    snprintf(buf,128, "%d", '?');
     setenv("key_qmark", buf, 1);
-    sprintf(buf, "%d", '_');
+    snprintf(buf,128, "%d", '_');
     setenv("key_underbar", buf, 1);
-    sprintf(buf, "%d", 0);
+    snprintf(buf,128, "%d", 0);
     setenv("nometa", buf, 1);
-    sprintf(buf, "%d", 1);
+    snprintf(buf,128, "%d", 1);
     setenv("meta", buf, 1);
-    sprintf(buf, "%d", kCAReverse);
+    snprintf(buf,128, "%d", kCAReverse);
     setenv("ma_reverse", buf, 1);
-    sprintf(buf, "%d", kCABold);
+    snprintf(buf,128, "%d", kCABold);
     setenv("ma_bold", buf, 1);
-    sprintf(buf, "%d", kCAUnderline);
+    snprintf(buf,128, "%d", kCAUnderline);
     setenv("ma_underline", buf, 1);
-    sprintf(buf, "%d", kCAWhite);
+    snprintf(buf,128, "%d", kCAWhite);
     setenv("ma_white", buf, 1);
-    sprintf(buf, "%d", kCABlue);
+    snprintf(buf,128, "%d", kCABlue);
     setenv("ma_blue", buf, 1);
-    sprintf(buf, "%d", kCACyan);
+    snprintf(buf,128, "%d", kCACyan);
     setenv("ma_cyan", buf, 1);
-    sprintf(buf, "%d", kCAGreen);
+    snprintf(buf,128, "%d", kCAGreen);
     setenv("ma_green", buf, 1);
-    sprintf(buf, "%d", kCAYellow);
+    snprintf(buf,128, "%d", kCAYellow);
     setenv("ma_yellow", buf, 1);
-    sprintf(buf, "%d", kCAMagenta);
+    snprintf(buf,128, "%d", kCAMagenta);
     setenv("ma_magenta", buf, 1);
-    sprintf(buf, "%d", kCARed);
+    snprintf(buf,128, "%d", kCARed);
     setenv("ma_red", buf, 1);
 }
 
@@ -889,7 +831,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.1.5", 1);
+    setenv("VERSION", "4.1.9", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -897,7 +839,7 @@ int main(int argc, char* argv[])
         fprintf(stderr, "$HOME is NULL.exit");
         exit(1);
     }
-    sprintf(gHomeDir, "%s/.mfiler3", home);
+    snprintf(gHomeDir, PATH_MAX, "%s/.mfiler3", home);
 
     if(access(gHomeDir, F_OK) != 0) {
 	char buf[PATH_MAX];
@@ -911,7 +853,7 @@ int main(int argc, char* argv[])
     }
 
     /// mfiler3の一時ディレクトリを保存しておく ///
-    sprintf(gTempDir, "%s/temp", gHomeDir);
+    snprintf(gTempDir, PATH_MAX, "%s/temp", gHomeDir);
     if(access(gTempDir, F_OK) != 0) {
         if(mkdir(gTempDir, 0700) < 0) {
             fprintf(stderr, "can't mkdir %s", gTempDir);
@@ -943,7 +885,7 @@ int main(int argc, char* argv[])
     for(i=1 ; i<argc; i++){
         // ファイル名
         if(argv[i][0] != '-') {         // オプションじゃなければ
-            strcpy(file_name, argv[i]);     // ファイル名とみなす
+            strncpy(file_name, argv[i], PATH_MAX);     // ファイル名とみなす
         }
         // 引数
         else {
@@ -954,12 +896,12 @@ int main(int argc, char* argv[])
                 case 'E':
                     if(i+2 < argc && atoi(argv[i+1]) != 0) {
                         pid = atoi(argv[i+1]);
-                        sprintf(send_cmd, "E%s", argv[i+2]);
+                        snprintf(send_cmd, BUFSIZ, "E%s", argv[i+2]);
                         i+=2;
                     }
                     else if(i+1 < argc) {
                         pid = -1;
-                        sprintf(send_cmd, "E%s", argv[i+1]);
+                        snprintf(send_cmd, BUFSIZ, "E%s", argv[i+1]);
                         i++;
                     }
                     else {
@@ -970,12 +912,12 @@ int main(int argc, char* argv[])
                 case 'e':
                     if(i+2 < argc && atoi(argv[i+1]) != 0) {
                         pid = atoi(argv[i+1]);
-                        sprintf(send_cmd, "e%s", argv[i+2]);
+                        snprintf(send_cmd, BUFSIZ, "e%s", argv[i+2]);
                         i+=2;
                     }
                     else if(i+1 < argc) {
                         pid = -1;
-                        sprintf(send_cmd, "e%s", argv[i+1]);
+                        snprintf(send_cmd, BUFSIZ, "e%s", argv[i+1]);
                         i++;
                     }
                     else {
@@ -986,7 +928,7 @@ int main(int argc, char* argv[])
 
                 case 'c':
                     if(i+1 < argc) {
-                        sprintf(send_cmd, "c%s", argv[i+1]);
+                        snprintf(send_cmd, BUFSIZ, "c%s", argv[i+1]);
                         i++;
                     }
                     else {
@@ -1006,7 +948,7 @@ int main(int argc, char* argv[])
     if(send_cmd[0] == 'E') {
         if(pid != -1) {
             char soc_name[PATH_MAX];
-            sprintf(soc_name, "%s/socket%d", gTempDir, pid);
+            snprintf(soc_name, PATH_MAX, "%s/socket%d", gTempDir, pid);
 
             if(access(soc_name, F_OK) == 0) {
                 int soc = socket(AF_UNIX, SOCK_DGRAM, 0);
@@ -1044,7 +986,7 @@ int main(int argc, char* argv[])
             while(entry = readdir(dir)) {
                 if(strstr(entry->d_name, "socket")) {
                     char soc_name[PATH_MAX];
-                    sprintf(soc_name, "%s/%s", gTempDir, entry->d_name);
+                    snprintf(soc_name, PATH_MAX, "%s/%s", gTempDir, entry->d_name);
 
                     int soc = socket(AF_UNIX, SOCK_DGRAM, 0);
                     if(soc < 0) {
@@ -1129,7 +1071,6 @@ int main(int argc, char* argv[])
     kanji_init();
     saphire_set_signal();
     saphire_init(kATConsoleApp, TRUE, kRSObject, FALSE);
-    //saphire_rehash();
     cmdline_completion_init();
     commands_init();
 
@@ -1139,7 +1080,7 @@ int main(int argc, char* argv[])
 
     /// ソケットの初期化 ///
     char soc_name[PATH_MAX];
-    sprintf(soc_name, "%s/socket%d", gTempDir, getpid());
+    snprintf(soc_name, PATH_MAX, "%s/socket%d", gTempDir, getpid());
     
     if(access(soc_name, F_OK) == 0) {
         unlink(soc_name);
@@ -1161,7 +1102,7 @@ int main(int argc, char* argv[])
 
     /// 名前付きパイプ初期化 ///
     char pipe_name[PATH_MAX];
-    sprintf(pipe_name, "%s/pipe_%d", gTempDir, getpid());
+    snprintf(pipe_name, PATH_MAX, "%s/pipe_%d", gTempDir, getpid());
 
     mkfifo(pipe_name, 0600);
 
@@ -1178,14 +1119,14 @@ int main(int argc, char* argv[])
     init_hooks();
 
     /// ランタイムスクリプト実行 ///
-    //read_rc_file();
     read_rc_file_compiled();
 
     /// ディレクトリを作成 ///
-    if(vector_size(gDirs) < 0) {
+    if(vector_size(gDirs) == 0) {
         if(strcmp(file_name, "") == 0) {
             char cwd[PATH_MAX];
-            mygetcwd(cwd);
+            mygetcwd(cwd, PATH_MAX);
+            strncat(cwd, "/", PATH_MAX);
 
             if(filer_new_dir(cwd, FALSE, ".+") < 0) {
                 fprintf(stderr, "invalid current directory\n");
@@ -1210,7 +1151,7 @@ int main(int argc, char* argv[])
     else if(vector_size(gDirs) == 1) {
         if(strcmp(file_name, "") == 0) {
             char cwd[PATH_MAX];
-            mygetcwd(cwd);
+            mygetcwd(cwd, PATH_MAX);
 
             if(filer_new_dir(cwd, FALSE, ".+") < 0) {
                 fprintf(stderr, "invalid current directory\n");
@@ -1420,10 +1361,10 @@ int main(int argc, char* argv[])
 
             if(pid != getpid()) {
                 char pid_buf[BUFSIZ];
-                sprintf(pid_buf, "%d", pid);
+                snprintf(pid_buf, BUFSIZ, "%d", pid);
                 if(strstr(string_c_str(ret), pid_buf) == NULL) {
                     char path[PATH_MAX];
-                    sprintf(path, "%s/%s", gTempDir, entry->d_name);
+                    snprintf(path, PATH_MAX, "%s/%s", gTempDir, entry->d_name);
                     unlink(path);
                 }
             }
@@ -1433,10 +1374,10 @@ int main(int argc, char* argv[])
 
             if(pid != getpid()) {
                 char pid_buf[BUFSIZ];
-                sprintf(pid_buf, "%d", pid);
+                snprintf(pid_buf, BUFSIZ, "%d", pid);
                 if(strstr(string_c_str(ret), pid_buf) == NULL) {
                     char path[PATH_MAX];
-                    sprintf(path, "%s/%s", gTempDir, entry->d_name);
+                    snprintf(path, PATH_MAX, "%s/%s", gTempDir, entry->d_name);
                     unlink(path);
                 }
             }
